# stateInfo

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Florian Dedov from RohitS 2022

## Examples of How To Use (Buggy Alpha Version)

returns state capital and language.

Example:
1) print(stateInfo.getCapital("Karnataka"))
   -> Bangalore

2) print(stateInfo.getLanguage("Karnataka"))
   -> Kannada